@@ -23,6 +23,9 @@ FAILEDOPERATION_APPIDISNULL = 'FailedOperation.AppIdIsNull'
 # FailedOperation.AppIdNotExited
 FAILEDOPERATION_APPIDNOTEXITED = 'FailedOperation.AppIdNotExited'
 
+# 应用ID不存在。
+FAILEDOPERATION_APPIDNOTFOUND = 'FailedOperation.AppIdNotFound'
+
 # 其子机构中存在用户的机构节点不能被删除。
 FAILEDOPERATION_CHILDORGNODEWITHUSERSCANNOTBEDELETED = 'FailedOperation.ChildOrgNodeWithUsersCannotBeDeleted'
 
@@ -47,6 +50,12 @@ FAILEDOPERATION_DELETEUSERGROUPFAILURE = 'FailedOperation.DeleteUserGroupFailure
 # 读取机构节点信息异常。
 FAILEDOPERATION_DESCRIBEORGNODEFAILURE = 'FailedOperation.DescribeOrgNodeFailure'
 
+# EntityType取值不合法。
+FAILEDOPERATION_ENTITYTYPENOTEXISTED = 'FailedOperation.EntityTypeNotExisted'
+
+# 期望返回的用户属性类型不存在。
+FAILEDOPERATION_EXPECTFIELDSNOTFOUND = 'FailedOperation.ExpectFieldsNotFound'
+
 # 用户组ID未找到。
 FAILEDOPERATION_GROUPIDNOTFOUND = 'FailedOperation.GroupIdNotFound'
 
@@ -86,6 +95,9 @@ FAILEDOPERATION_PERSONNOTFOUND = 'FailedOperation.PersonNotFound'
 # 从用户组中移除用户异常。
 FAILEDOPERATION_REMOVEUSERSFROMUSERGROUPFAILURE = 'FailedOperation.RemoveUsersFromUserGroupFailure'
 
+# 列表搜索条件不合法。
+FAILEDOPERATION_SEARCHCRITERIAISILLEGAL = 'FailedOperation.SearchCriteriaIsIllegal'
+
 # 设定的时间格式不合法。
 FAILEDOPERATION_TIMEFORMATISILLEGAL = 'FailedOperation.TimeFormatIsIllegal'
 
@@ -104,6 +116,9 @@ FAILEDOPERATION_USERGROUPNOTEXIST = 'FailedOperation.UserGroupNotExist'
 # 用户组不存在。
 FAILEDOPERATION_USERGROUPNOTEXISTED = 'FailedOperation.UserGroupNotExisted'
 
+# 用户信息分页展示的排列属性不合法。
+FAILEDOPERATION_USERINFOSORTKEYISILLEGAL = 'FailedOperation.UserInfoSortKeyIsIllegal'
+
 # 用户名字已存在。
 FAILEDOPERATION_USERNAMEEXISTED = 'FailedOperation.UserNameExisted'
 
@@ -113,6 +128,9 @@ FAILEDOPERATION_USERNOTEXISTEDINUSERGROUP = 'FailedOperation.UserNotExistedInUse
 # 用户手机已存在。
 FAILEDOPERATION_USERPHONEEXISTED = 'FailedOperation.UserPhoneExisted'
 
+# 参数不合法。
+INVALIDPARAMETER_PARAMETERILLEGAL = 'InvalidParameter.ParameterIllegal'
+
 # 参数不合法。
 INVALIDPARAMETER_PARAMETERLLLEGAL = 'InvalidParameter.Parameterlllegal'
 
